@@ -91,7 +91,9 @@ sub _get_dbh ( $self, $cb ) {
     }
 
     if ( $self->{_get_dbh_queue}->@* > $self->{backlog} ) {
-        $cb->( result( [ 500, 'DBH is busy' ] ), undef );
+        warn 'DBI: backlog queue is full';
+
+        $cb->( result( [ 500, 'backlog queue is full' ] ), undef );
 
         return;
     }
@@ -257,9 +259,9 @@ PERL
 ## |======+======================+================================================================================================================|
 ## |    3 |                      | Subroutines::ProhibitUnusedPrivateSubroutines                                                                  |
 ## |      | 81                   | * Private subroutine/method '_get_dbh' declared but not used                                                   |
-## |      | 150                  | * Private subroutine/method '_get_schema_patch_table_query' declared but not used                              |
+## |      | 152                  | * Private subroutine/method '_get_schema_patch_table_query' declared but not used                              |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 209, 231             | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 211, 233             | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
